@@ -18,8 +18,8 @@ from termcolor import colored
 
 logging.root.setLevel(logging.NOTSET)
 logger = logging.getLogger('utils_logger')
-logger.addHandler(MongoHandler(host='localhost', database_name='logs', collection='utils_atm_logs', reuse=True))
-# logger.addHandler(MongoHandler(host='mongodb://mongo-database:27018/', database_name='logs', collection='utils_atm_logs', reuse=True))
+#logger.addHandler(MongoHandler(host='localhost', database_name='logs', collection='utils_atm_logs', reuse=True))
+logger.addHandler(MongoHandler(host='mongodb://mongo-database:27018/', database_name='logs', collection='utils_atm_logs', reuse=True))
 # TRAN_TYPE_BUY = "BUY"
 # TRAN_TYPE_SELL = "SELL"
 # QUANTITY = 50
